@@ -27,7 +27,6 @@ from bottle import static_file
 from optuna.exceptions import DuplicatedStudyError
 from optuna.storages import BaseStorage
 from optuna.storages import RDBStorage
-from optuna.storages import RedisStorage
 from optuna.study import StudyDirection
 from optuna.study import StudySummary
 from optuna.trial import FrozenTrial
@@ -54,9 +53,11 @@ BottleView = TypeVar("BottleView", bound=Callable[..., BottleViewReturn])
 
 logger = logging.getLogger(__name__)
 
+# Static files
 BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 STATIC_DIR = os.path.join(BASE_DIR, "public")
 IMG_DIR = os.path.join(BASE_DIR, "img")
+cached_path_exists = functools.lru_cache(maxsize=10)(os.path.exists)
 
 # In-memory trials cache
 trials_cache_lock = threading.Lock()
@@ -158,6 +159,19 @@ def get_study_summary(storage: BaseStorage, study_id: int) -> Optional[StudySumm
     return None
 
 
+def create_new_study(
+    storage: BaseStorage, study_name: str, directions: List[StudyDirection]
+) -> int:
+    if version.parse(optuna_ver) >= version.Version("3.1.0.dev") and version.parse(
+        optuna_ver
+    ) != version.Version("3.1.0b0"):
+        study_id = storage.create_new_study(directions, study_name=study_name)  # type: ignore
+    else:
+        study_id = storage.create_new_study(study_name)  # type: ignore
+        storage.set_study_directions(study_id, directions)  # type: ignore
+    return study_id
+
+
 def get_trials(storage: BaseStorage, study_id: int, ttl_seconds: int = 10) -> List[FrozenTrial]:
     with trials_cache_lock:
         trials = trials_cache.get(study_id, None)
@@ -240,28 +254,24 @@ def create_app(storage: BaseStorage, debug: bool = False) -> Bottle:
     @json_api_view
     def create_study() -> BottleViewReturn:
         study_name = request.json.get("study_name", None)
-        directions = request.json.get("directions", [])
+        request_directions = [d.lower() for d in request.json.get("directions", [])]
         if (
             study_name is None
-            or len(directions) == 0
-            or not all([d in ("minimize", "maximize") for d in directions])
+            or len(request_directions) == 0
+            or not all([d in ("minimize", "maximize") for d in request_directions])
         ):
             response.status = 400  # Bad request
             return {"reason": "You need to set study_name and direction"}
 
+        directions = [
+            StudyDirection.MAXIMIZE if d == "maximize" else StudyDirection.MINIMIZE
+            for d in request_directions
+        ]
         try:
-            study_id = storage.create_new_study(study_name)
+            study_id = create_new_study(storage, study_name, directions)
         except DuplicatedStudyError:
             response.status = 400  # Bad request
-            return {"reason": f"'{study_name}' is already exists"}
-
-        storage.set_study_directions(
-            study_id,
-            [
-                StudyDirection.MAXIMIZE if d.lower() == "maximize" else StudyDirection.MINIMIZE
-                for d in directions
-            ],
-        )
+            return {"reason": f"'{study_name}' already exists"}
 
         summary = get_study_summary(storage, study_id)
         if summary is None:
@@ -297,15 +307,21 @@ def create_app(storage: BaseStorage, debug: bool = False) -> Bottle:
             response.status = 404  # Not found
             return {"reason": f"study_id={study_id} is not found"}
         trials = get_trials(storage, study_id)
-        intersection, union, has_intermeridate_values = get_cached_extra_study_property(
-            study_id, trials
-        )
+        (
+            # TODO: intersection_search_space and union_search_space look more clear since now we
+            # have union_user_attrs.
+            intersection,
+            union,
+            union_user_attrs,
+            has_intermediate_values,
+        ) = get_cached_extra_study_property(study_id, trials)
         return serialize_study_detail(
             summary,
             trials[after:],
             intersection,
             union,
-            has_intermeridate_values,
+            union_user_attrs,
+            has_intermediate_values,
         )
 
     @app.get("/api/studies/<study_id:int>/param_importances")
@@ -361,7 +377,7 @@ def create_app(storage: BaseStorage, debug: bool = False) -> Bottle:
     def send_static(filename: str) -> BottleViewReturn:
         if not debug and "gzip" in request.headers["Accept-Encoding"]:
             gz_filename = filename.strip("/\\") + ".gz"
-            if os.path.exists(os.path.join(STATIC_DIR, gz_filename)):
+            if cached_path_exists(os.path.join(STATIC_DIR, gz_filename)):
                 filename = gz_filename
         return static_file(filename, root=STATIC_DIR)
 
@@ -387,7 +403,9 @@ def _frozen_study_to_study_summary(frozen_study: "FrozenStudy") -> StudySummary:
 def get_storage(storage: Union[str, BaseStorage]) -> BaseStorage:
     if isinstance(storage, str):
         if storage.startswith("redis"):
-            return RedisStorage(storage)
+            raise ValueError(
+                "RedisStorage is unsupported from Optuna v3.1 or Optuna Dashboard v0.8.0"
+            )
         else:
             return RDBStorage(storage, skip_compatibility_check=True)
     return storage
